@@ -203,7 +203,7 @@ class ChIPSeqPeaks():
                 (
                     self.macs2_path, 'callpeak',
                     '-B',
-                    '--extsize', self.extsize,
+                    '--extsize', str(self.extsize),
                     '--keep-dup', 'all',
                     '--treatment', temp_treatment_bam.name,
                     '--name', temp_name,
